==> nextcloud-21.0.1-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/si.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "ක්‍රියාකාරකම",
    "An error occurred while loading activities" : "ක්‍රියාකාරකම් පූරණය කිරීමේදී දෝෂයක් ඇතිවිය",
    "No activity yet" : "තවම ක්‍රියාකාරකමක් නොමැත",
    "Load more activities" : "තවත් ක්‍රියාකාරකම් පූරණය කරන්න",
    "Copied!" : "පිටපත් කළා!",
    "Not supported!" : "සහාය නොදක්වයි!",
    "Press ⌘-C to copy." : "පිටපත් කිරීමට ⌘-C ඔබන්න.",
    "Press Ctrl-C to copy." : "පිටපත් කිරීමට Ctrl-C ඔබන්න.",
    "{name} (invisible)" : "{name} (නොපෙනෙන)",
    "{name} (restricted)" : "{name} (සීමිත)",
    "Home" : "මුල් පිටුව",
    "in {path}" : "{path} තුළ",
    "Today" : "අද",
    "Yesterday" : "ඊයේ",
    "Open file" : "ගොනුව විවෘත කරන්න",
    "Your settings have been updated." : "ඔබගේ සැකසුම් යාවත්කාලීන කර ඇත.",
    "Settings have been updated." : "සැකසුම් යාවත්කාලීන කර ඇත.",
    "All activities" : "සියලුම ක්‍රියාකාරකම්",
    "By others" : "අන් අය විසින්",
    "By you" : "ඔබ විසින්",
    "Activity notification for %s" : "%s සඳහා ක්‍රියාකාරකම් දැනුම්දීම",
    "Hello %s" : "ආයුබෝවන් %s",
    "Hello %s," : "ආයුබෝවන් %s,",
    "Mail" : "තැපෑල",
    "Notifications" : "දැනුම්දීම්",
    "Enable notification emails" : "දැනුම්දීම් විද්‍යුත් තැපෑල සබල කරන්න",
    "Default settings" : "සාමාන්‍ය සැකසුම්",
    "As soon as possible" : "හැකි ඉක්මනින්",
    "Daily" : "දිනපතා",
    "Weekly" : "සතිපතා",
    "Settings" : "සැකසුම්",
    "No more events to load" : "පූරණය කිරීමට තවත් සිදුවීම් නොමැත",
    "Send activity emails" : "ක්‍රියාකාරකම් විද්‍යුත් තැපෑල යවන්න",
    "Notify about your own actions via email" : "ඔබගේ ක්‍රියාමාර්ග පිළිබඳ විද්‍යුත් තැපෑලෙන් දැනුම් දෙන්න"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/si.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "පිටපත් කළා!",
    "Not supported!" : "සහාය නොදක්වයි!",
    "Press ⌘-C to copy." : "පිටපත් කිරීමට ⌘-C ඔබන්න.",
    "Press Ctrl-C to copy." : "පිටපත් කිරීමට Ctrl-C ඔබන්න.",
    "{name} (invisible)" : "{name} (නොපෙනෙන)",
    "{name} (restricted)" : "{name} (සීමිත)",
    "Home" : "මුල් පිටුව",
    "in {path}" : "{path} තුළ",
    "Today" : "අද",
    "Yesterday" : "ඊයේ",
    "Your settings have been updated." : "ඔබගේ සැකසුම් යාවත්කාලීන කර ඇත.",
    "Settings have been updated." : "සැකසුම් යාවත්කාලීන කර ඇත.",
    "Recent activity" : "මෑත ක්‍රියාකාරකම",
    "_and %n more _::_and %n more _" : ["සහ තවත් %n","සහ තවත් %n"],
    "All activities" : "සියළුම ක්‍රියාකාරකම්",
    "By others" : "අන් අය විසින්",
    "By you" : "ඔබ විසින්",
    "Activity notification for %s" : "%s සඳහා ක්‍රියාකාරකම් දැනුම්දීම",
    "Hello %s" : "ආයුබෝවන් %s",
    "Hello %s," : "ආයුබෝවන් %s,",
    "Mail" : "තැපෑල",
    "Activity" : "ක්‍රියාකාරකම",
    "Notifications" : "දැනුම්දීම්",
    "No activity yet" : "තවම ක්‍රියාකාරකමක් නොමැත",
    "activities" : "ක්‍රියාකාරකම්",
    "No activities" : "ක්‍රියාකාරකම් නැත",
    "Enable notification emails" : "දැනුම්දීම් විද්‍යුත් තැපෑල සබල කරන්න",
    "Default settings" : "සාමාන්‍ය සැකසුම්",
    "As soon as possible" : "හැකි ඉක්මනින්",
    "Daily" : "දිනපතා",
    "Weekly" : "සතිපතා",
    "Settings" : "සැකසුම්",
    "No more events to load" : "පූරණය කිරීමට තවත් සිදුවීම් නොමැත",
    "An error occurred while loading activities" : "ක්‍රියාකාරකම් පූරණය කිරීමේදී දෝෂයක් ඇතිවිය",
    "Load more activities" : "තවත් ක්‍රියාකාරකම් පූරණය කරන්න",
    "Open file" : "ගොනුව විවෘත කරන්න"
},
"nplurals=2; plural=(n != 1);");
